@@ -46,18 +46,22 @@ class DynamicColumn(TimeModelMixin, UserModelMixin, StatusModelMixin):
     BOOLEAN = 1
     CHOICE = 2
     DATE = 3
-    FLOAT = 4
-    NUMBER = 5
-    TEXT = 6
-    TEXT_BLOCK = 7
+    DATETIME = 4
+    FLOAT = 5
+    NUMBER = 6
+    TEXT = 7
+    TEXT_BLOCK = 8
+    TIME = 9
     VALUE_TYPES = (
         (BOOLEAN, _("Boolean")),
         (CHOICE, _("Choice")),
         (DATE, _("Date")),
+        (DATETIME, ("Date Time")),
         (FLOAT, _("Floating Point")),
         (NUMBER, _("Number")),
         (TEXT, _("Text")),
         (TEXT_BLOCK, _("Text Block")),
+        (TIME, ("Time")),
         )
     VALUE_TYPES_MAP = dict(VALUE_TYPES)
     NO = False
@@ -139,8 +143,7 @@ class DynamicColumn(TimeModelMixin, UserModelMixin, StatusModelMixin):
     _collection_producer.allow_tags = True
 
     def get_choice_relation_object_and_field(self):
-        return dcolumn_manager.get_relation_model_field(self.value_type)
-
+        return dcolumn_manager.get_relation_model_field(self.relation)
 
 
 #
@@ -239,6 +242,10 @@ class ColumnCollection(TimeModelMixin, UserModelMixin, StatusModelMixin):
     def __unicode__(self):
         return u"{}-{}".format(self.name, self.updated.isoformat())
 
+    def save(self, *args, **kwargs):
+        log.debug("kwargs: %s", kwargs)
+        super(ColumnCollection, self).save(*args, **kwargs)
+
 
 #
 # CollectionBase
@@ -316,7 +323,7 @@ class CollectionBase(TimeModelMixin, UserModelMixin, StatusModelMixin):
 
         Arguments:
           slug  -- The slug associated with the key value pair.
-          value -- The value can be textor an object to get the value from.
+          value -- The value can be text or an object to get the value from.
           field -- The field used to get the value on the object.
           force -- Default is False, do not save empty strings or None objects
                    else True save empty strings only.
